/*
 * Python object definition of the libpff item
 *
 * Copyright (C) 2008-2016, Joachim Metz <joachim.metz@gmail.com>
 *
 * Refer to AUTHORS for acknowledgements.
 *
 * This software is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software.  If not, see <http://www.gnu.org/licenses/>.
 */

#if !defined( _PYPFF_ITEM_H )
#define _PYPFF_ITEM_H

#include <common.h>
#include <types.h>

#include "pypff_file.h"
#include "pypff_libcerror.h"
#include "pypff_libpff.h"
#include "pypff_python.h"

#if defined( __cplusplus )
extern "C" {
#endif

typedef struct pypff_item pypff_item_t;

struct pypff_item
{
	/* Python object initialization
	 */
	PyObject_HEAD

	/* The libpff item
	 */
	libpff_item_t *item;

	/* The libpff record set
	 */
	libpff_item_t *record_set;

	/* The file object
	 */
	pypff_file_t *file_object;
};

extern PyMethodDef pypff_item_object_methods[];
extern PyTypeObject pypff_item_type_object;

PyObject *pypff_item_new(
           PyTypeObject *type_object,
           libpff_item_t *item,
           pypff_file_t *file_object );

PyObject *pypff_item_new_with_record_set(
           PyTypeObject *type_object,
           libpff_item_t *item,
           pypff_file_t *file_object );

int pypff_item_init(
     pypff_item_t *pypff_item );

void pypff_item_free(
      pypff_item_t *pypff_item );

PyObject *pypff_item_get_number_of_record_sets(
           pypff_item_t *pypff_item,
           PyObject *arguments );

PyObject *pypff_item_get_record_set_by_index(
           pypff_item_t *pypff_item,
           int record_set_index );

PyObject *pypff_item_get_record_set(
           pypff_item_t *pypff_item,
           PyObject *arguments,
           PyObject *keywords );

PyObject *pypff_item_get_record_sets(
           pypff_item_t *pypff_item,
           PyObject *arguments );

PyObject *pypff_item_get_display_name(
           pypff_item_t *pypff_item,
           PyObject *arguments );

PyObject *pypff_item_get_number_of_sub_items(
           pypff_item_t *pypff_item,
           PyObject *arguments );

PyObject *pypff_item_get_sub_item_by_index(
           pypff_item_t *pypff_item,
           int sub_item_index );

PyObject *pypff_item_get_sub_item(
           pypff_item_t *pypff_item,
           PyObject *arguments,
           PyObject *keywords );

PyObject *pypff_item_get_sub_items(
           pypff_item_t *pypff_item,
           PyObject *arguments );

#if defined( __cplusplus )
}
#endif

#endif

